package dev.fitko.fitconnect.client.steps.sender;

import java.util.Map;
import java.util.UUID;

public interface EncryptedAttachmentsStep {

    /**
     * Sends the submission with a list of already encrypted attachments
     *
     * @param encryptedAttachments map of encrypted attachments on attachment UUIDs
     *
     * @return the next step where additional encrypted data can be added to the submission
     */
    EncryptedDataStep withEncryptedAttachments(Map<UUID, String> encryptedAttachments);

    /**
     * Sends the submission with an attachments
     *
     * @param attachmentId unique identifier attachment that is uploaded
     * @param attachment encrypted attachment that is sent with the submission
     * @return the next step where additional data can be added to the submission
     */
    EncryptedDataStep withEncryptedAttachment(UUID attachmentId, String attachment);

    /**
     * JSON data as encrypted JWE string.
     *
     * @param encryptedData encrypted json string
     * @return next step to submit the data
     */
    EncryptedMetadataStep withEncryptedJsonData(String encryptedData);

    /**
     * XML data as encrypted JWE string.
     *
     * @param encryptedData encrypted xml string
     * @return next step to submit the data
     */
    EncryptedMetadataStep withEncryptedXmlData(String encryptedData);
}

